@@ -7,7 +7,7 @@ data(specsdm91)
 u <- usl(throughput ~ load, specsdm91)
 
 # Calculate where peak scalability is reached
-signif(peak.scalability(u), 2)
+stopifnot(all.equal(peak.scalability(u), 96.51956, 0.0001))
 
 # Calculate scalability for different coefficients
-signif(peak.scalability(u, 0.001, 0.00001), 2)
+stopifnot(all.equal(peak.scalability(u, 0.001, 0.00001), 316.0696, 0.0001))
